--------------------------------------------------------------------------------
-- Supertobi
-- Tobchen Carnage Contest Weapon
-- Script by Tobchen, July 2010, www.tobchen.de
--------------------------------------------------------------------------------

-- Setup Tables
if cc==nil then cc={} end
cc.supertobi={}
cc.supertobi.supertobi={}

-- Load & Prepare Ressources
cc.supertobi.gfx_icon=loadgfx("weapons/tobchen_supertobi_icon.png")
setmidhandle(cc.supertobi.gfx_icon)
cc.supertobi.gfx_hud=loadgfx("weapons/tobchen_supertobi_hud.png")
setmidhandle(cc.supertobi.gfx_hud)

cc.supertobi.gfx_up=loadgfx("weapons/tobchen_supertobi_up.png")
setmidhandle(cc.supertobi.gfx_up)
cc.supertobi.gfx_down=loadgfx("weapons/tobchen_supertobi_down.png")
setmidhandle(cc.supertobi.gfx_down)
cc.supertobi.gfx_right=loadgfx("weapons/tobchen_supertobi_right.png")
setmidhandle(cc.supertobi.gfx_right)
cc.supertobi.gfx_left=loadgfx("weapons/tobchen_supertobi_left.png")
setmidhandle(cc.supertobi.gfx_left)
cc.supertobi.gfx_flying=loadgfx("weapons/tobchen_supertobi_flying.png")
setmidhandle(cc.supertobi.gfx_flying)

cc.supertobi.sfx_attack=loadsfx("tobchen_supertobi.wav")

--------------------------------------------------------------------------------
-- Weapon: Supertobi
--------------------------------------------------------------------------------

cc.supertobi.id=addweapon("cc.supertobi", "Supertobi", cc.supertobi.gfx_icon, 0, 2) -- Add Weapon (0 uses, first in round 2)

-- Draw
function cc.supertobi.draw()
	-- Do nothing
end

-- Attack
function cc.supertobi.attack(attack)
	if (weapon_shots <= 0 and attack == 1) then
		-- No more weapon switching!
		useweapon(0)
		weapon_used = 1
		-- No more player control!
		playercontrol(0)
		-- Announce him
		playsound(cc.supertobi.sfx_attack)
		
		-- Supertobi
		id = createprojectile(cc.supertobi.supertobi.id)
		projectiles[id] = {}
		projectiles[id].x = getmapwidth()/2
		projectiles[id].y = -100
		projectiles[id].sx = 0
		projectiles[id].sy = 0
		projectiles[id].frame = 0 -- 0: flying; 1: up; 2: down; 3: left; 4: right
	end
end

--------------------------------------------------------------------------------
-- Projectile: Supertobi
--------------------------------------------------------------------------------

-- Add projectile
cc.supertobi.supertobi.id = addprojectile("cc.supertobi.supertobi")

-- Draw
function cc.supertobi.supertobi.draw(id)
	--setcolor(255,255,255)
	--setscale(1,1)
	
	-- Draw projectile
	if weapon_used > 0 then
		setblend(blend_alpha)
		setalpha(1)
		setcolor(255,255,255)
		setscale(1,1)
		setrotation(0)
	
		if projectiles[id].frame == 0 then
			drawimage(cc.supertobi.gfx_flying, projectiles[id].x, projectiles[id].y)
		elseif projectiles[id].frame == 1 then
			drawimage(cc.supertobi.gfx_up, projectiles[id].x, projectiles[id].y)
		elseif projectiles[id].frame == 2 then
			drawimage(cc.supertobi.gfx_down, projectiles[id].x, projectiles[id].y)
		elseif projectiles[id].frame == 3 then
			drawimage(cc.supertobi.gfx_left, projectiles[id].x, projectiles[id].y)
		elseif projectiles[id].frame == 4 then
			drawimage(cc.supertobi.gfx_right, projectiles[id].x, projectiles[id].y)
		end
		
		drawimage(cc.supertobi.gfx_hud, projectiles[id].x, projectiles[id].y+36)
	end
	
	-- Draw arrow if out of screen
	outofscreenarrow(projectiles[id].x, projectiles[id].y)
end

-- Update
function cc.supertobi.supertobi.update(id)
	-- Reset speed
	projectiles[id].sx = 0
	projectiles[id].sy = 0
	projectiles[id].frame = 0
	
	-- Control by player
	if weapon_used == 1 then
		if keydown(key_up) == 1 then
			projectiles[id].sy = -4
			projectiles[id].frame = 1
		elseif keydown(key_down) == 1 then
			projectiles[id].sy = 4
			projectiles[id].frame = 2
		end
		
		if keydown(key_left) == 1 then
			if projectiles[id].frame == 0 then
				projectiles[id].sx = -4
			else
				projectiles[id].sy = projectiles[id].sy*3/4
				projectiles[id].sx = -3
			end
			
			projectiles[id].frame = 3				
		elseif keydown(key_right) == 1 then
			if projectiles[id].frame == 0 then
				projectiles[id].sx = 4
			else
				projectiles[id].sy = projectiles[id].sy*3/4
				projectiles[id].sx = 3
			end
			
			projectiles[id].frame = 4
		end
	end
	
	-- Move (in substep loop for optimal collision precision)
	msubt = math.ceil(math.max(math.abs(projectiles[id].sx), math.abs(projectiles[id].sy))/3)
	msubx = projectiles[id].sx/msubt
	msuby = projectiles[id].sy/msubt
	for i = 1, msubt, 1 do
		projectiles[id].x = projectiles[id].x+msubx
		projectiles[id].y = projectiles[id].y+msuby
		
		-- Collision
		if collision(col10x10, projectiles[id].x, projectiles[id].y, 1, 1) == 1 then
			-- Splatter
			playsound(sfx_splatter2)
			-- Cause damage
			arealdamage(projectiles[id].x, projectiles[id].y, 100, 50)
			-- Destroy terrain
			terrainexplosion(projectiles[id].x, projectiles[id].y, 25, 1)
			-- Crater
			grey=math.random(0,40)
			terrainalphaimage(gfx_crater50, projectiles[id].x, projectiles[id].y, math.random(6,9)*0.1, grey, grey, grey)
			-- Free projectile
			freeprojectile(id)
			-- End Turn
			endturn()
		end
	end
	
	-- Turn end
	if getframesleft()<5 then
		-- Vanishing-Effect
		particle(p_smoke, projectiles[id].x+9, projectiles[id].y+3) -- The yellow one
		particlealpha(1.0)
		particlecolor(255, 220, 0)
		particlesize(20, 20)
		particlefadealpha(0.05)
		particle(p_smoke, projectiles[id].x-9, projectiles[id].y+3) -- The red one
		particlealpha(1.0)
		particlecolor(220, 0, 0)
		particlesize(20, 20)
		particlefadealpha(0.05)
		particle(p_smoke, projectiles[id].x, projectiles[id].y-12) -- The blue one
		particlealpha(1.0)
		particlecolor(0, 128, 255)
		particlesize(20, 20)
		particlefadealpha(0.05)
		
		-- Free projectile
		freeprojectile(id)
		-- End Turn
		endturn()
	end
	
	-- Scroll to projectile
	scroll(projectiles[id].x, projectiles[id].y)
end